Enum Entry

1.36.0 · Source
pub enum Entry<'a, K, V, A = Global>
where K: 'a, V: 'a, A: Allocator + Clone,
{ Vacant(VacantEntry<'a, K, V, A>), Occupied(OccupiedEntry<'a, K, V, A>), }
Available on crate feature wayland and Linux only.
A view into a single entry in a map, which may either be vacant or occupied.

This enum is constructed from the entry method on BTreeMap.

Variants

1.36.0

Vacant(VacantEntry<'a, K, V, A>)

A vacant entry.

1.36.0

Occupied(OccupiedEntry<'a, K, V, A>)

An occupied entry.

Implementations

Source

impl<'a, K, V, A> Entry<'a, K, V, A>
where K: Ord, A: Allocator + Clone,

1.0.0 · Source

pub fn or_insert(self, default: V) -> &'a mut V

Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.

Examples
use std::collections::BTreeMap;

let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert(12);

assert_eq!(map["poneyland"], 12);
1.0.0 · Source

pub fn or_insert_with<F>(self, default: F) -> &'a mut V
where F: FnOnce() -> V,

Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.

Examples
use std::collections::BTreeMap;

let mut map: BTreeMap<&str, String> = BTreeMap::new();
let s = "hoho".to_string();

map.entry("poneyland").or_insert_with(|| s);

assert_eq!(map["poneyland"], "hoho".to_string());
1.50.0 · Source

pub fn or_insert_with_key<F>(self, default: F) -> &'a mut V
where F: FnOnce(&K) -> V,

Ensures a value is in the entry by inserting, if empty, the result of the default function.

This method allows for generating key-derived values for insertion by providing the default function a reference to the key that was moved during the .entry(key) method call.

The reference to the moved key is provided so that cloning or copying the key is unnecessary, unlike with .or_insert_with(|| ... ).

Examples
use std::collections::BTreeMap;

let mut map: BTreeMap<&str, usize> = BTreeMap::new();

map.entry("poneyland").or_insert_with_key(|key| key.chars().count());

assert_eq!(map["poneyland"], 9);
1.10.0 · Source

pub fn key(&self) -> &K

Returns a reference to this entry’s key.

Examples
use std::collections::BTreeMap;

let mut map: BTreeMap<&str, usize> = BTreeMap::new();
assert_eq!(map.entry("poneyland").key(), &"poneyland");
1.26.0 · Source

pub fn and_modify<F>(self, f: F) -> Entry<'a, K, V, A>
where F: FnOnce(&mut V),

Provides in-place mutable access to an occupied entry before any potential inserts into the map.

Examples
use std::collections::BTreeMap;

let mut map: BTreeMap<&str, usize> = BTreeMap::new();

map.entry("poneyland")
   .and_modify(|e| { *e += 1 })
   .or_insert(42);
assert_eq!(map["poneyland"], 42);

map.entry("poneyland")
   .and_modify(|e| { *e += 1 })
   .or_insert(42);
assert_eq!(map["poneyland"], 43);
pub fn insert_entry(self, value: V) -> OccupiedEntry<'a, K, V, A>

🔬This is a nightly-only experimental API. (btree_entry_insert)

Sets the value of the entry, and returns an OccupiedEntry.

Examples
#![feature(btree_entry_insert)]
use std::collections::BTreeMap;

let mut map: BTreeMap<&str, String> = BTreeMap::new();
let entry = map.entry("poneyland").insert_entry("hoho".to_string());

assert_eq!(entry.key(), &"poneyland");
Source

impl<'a, K, V, A> Entry<'a, K, V, A>
where K: Ord, V: Default, A: Allocator + Clone,

1.28.0 · Source

pub fn or_default(self) -> &'a mut V

Ensures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.

Examples
use std::collections::BTreeMap;

let mut map: BTreeMap<&str, Option<usize>> = BTreeMap::new();
map.entry("poneyland").or_default();

assert_eq!(map["poneyland"], None);