pub struct OccupiedEntry<'a, K, V, A = Global>{ /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
A view into an occupied entry in a BTreeMap.
It is part of the Entry enum.
Implementations
Sourceimpl<'a, K, V, A> OccupiedEntry<'a, K, V, A>
impl<'a, K, V, A> OccupiedEntry<'a, K, V, A>
1.10.0 · Sourcepub fn key(&self) -> &K
pub fn key(&self) -> &K
Gets a reference to the key in the entry.
Examples
use std::collections::BTreeMap;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert(12);
assert_eq!(map.entry("poneyland").key(), &"poneyland");1.12.0 · Sourcepub fn remove_entry(self) -> (K, V)
pub fn remove_entry(self) -> (K, V)
Take ownership of the key and value from the map.
Examples
use std::collections::BTreeMap;
use std::collections::btree_map::Entry;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert(12);
if let Entry::Occupied(o) = map.entry("poneyland") {
// We delete the entry from the map.
o.remove_entry();
}
// If now try to get the value, it will panic:
// println!("{}", map["poneyland"]);1.0.0 · Sourcepub fn get(&self) -> &V
pub fn get(&self) -> &V
Gets a reference to the value in the entry.
Examples
use std::collections::BTreeMap;
use std::collections::btree_map::Entry;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert(12);
if let Entry::Occupied(o) = map.entry("poneyland") {
assert_eq!(o.get(), &12);
}1.0.0 · Sourcepub fn get_mut(&mut self) -> &mut V
pub fn get_mut(&mut self) -> &mut V
Gets a mutable reference to the value in the entry.
If you need a reference to the OccupiedEntry that may outlive the
destruction of the Entry value, see into_mut.
Examples
use std::collections::BTreeMap;
use std::collections::btree_map::Entry;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert(12);
assert_eq!(map["poneyland"], 12);
if let Entry::Occupied(mut o) = map.entry("poneyland") {
*o.get_mut() += 10;
assert_eq!(*o.get(), 22);
// We can use the same Entry multiple times.
*o.get_mut() += 2;
}
assert_eq!(map["poneyland"], 24);1.0.0 · Sourcepub fn into_mut(self) -> &'a mut V
pub fn into_mut(self) -> &'a mut V
Converts the entry into a mutable reference to its value.
If you need multiple references to the OccupiedEntry, see get_mut.
Examples
use std::collections::BTreeMap;
use std::collections::btree_map::Entry;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert(12);
assert_eq!(map["poneyland"], 12);
if let Entry::Occupied(o) = map.entry("poneyland") {
*o.into_mut() += 10;
}
assert_eq!(map["poneyland"], 22);1.0.0 · Sourcepub fn insert(&mut self, value: V) -> V
pub fn insert(&mut self, value: V) -> V
Sets the value of the entry with the OccupiedEntry’s key,
and returns the entry’s old value.
Examples
use std::collections::BTreeMap;
use std::collections::btree_map::Entry;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert(12);
if let Entry::Occupied(mut o) = map.entry("poneyland") {
assert_eq!(o.insert(15), 12);
}
assert_eq!(map["poneyland"], 15);1.0.0 · Sourcepub fn remove(self) -> V
pub fn remove(self) -> V
Takes the value of the entry out of the map, and returns it.
Examples
use std::collections::BTreeMap;
use std::collections::btree_map::Entry;
let mut map: BTreeMap<&str, usize> = BTreeMap::new();
map.entry("poneyland").or_insert(12);
if let Entry::Occupied(o) = map.entry("poneyland") {
assert_eq!(o.remove(), 12);
}
// If we try to get "poneyland"'s value, it'll panic:
// println!("{}", map["poneyland"]);Trait Implementations